@@ -5,7 +5,7 @@ use warnings;
 use vars qw($VERSION);
 use LWP::UserAgent;
 
-$VERSION = '1.11';
+$VERSION = '1.6';
 
 sub new
 {
@@ -13,7 +13,7 @@ sub new
     my %par = @_;
     my $self;
   
-    $self->{ua} = LWP::UserAgent->new(agent => $par{agent} || 'Opera 11.1') or return;
+    $self->{ua} = LWP::UserAgent->new(agent => $par{agent} || 'Opera 10.0') or return;
     $self->{ua}->proxy('http', $par{proxy}) if $par{proxy};
     $self->{ua}->timeout($par{timeout})     if $par{timeout};
 
@@ -26,14 +26,46 @@ sub get
 
     return unless defined $domain;
 
-    my $res = $self->{ua}->get("http://xml.alexa.com/data?cli=10&dat=nsa&url=$domain");
+    my $res = $self->{ua}->get("http://www.alexa.com/siteinfo/$domain");
     return $res->status_line if !$res->is_success;
 
-    my ($rank) = $res->content =~ /<POPULARITY URL=".+" TEXT="(\d+)"/i;
+    my $cont = $res->content; $cont =~ s/[\r\n]//g;
+
+    my ($updown, $rank) = $cont =~ /<div class="data (up|down|steady)"><img.*?\/>\s+([\d,]+)<\//i;
 
     return $rank;
 }
 
+sub get_country_rank
+{
+    my $self = shift;
+    my $par  = { @_ };
+
+    return unless defined $par->{Domain};
+    return unless defined $par->{Country};
+
+    my $res = $self->{ua}->get("http://www.alexa.com/siteinfo/$par->{Domain}");
+    return $res->status_line if !$res->is_success;
+
+    my $cont = $res->content; $cont =~ s/[\r\n]//g;
+
+    return 0 unless $cont =~ /is ranked around the world(.+?)<\/ul>/gs;
+  
+    my $listdata = $1;
+
+    while ( $listdata =~ /<li class="geo_percentages">(.+?)<\/li>/igs ) {
+        my $item = $1;
+
+        if ( $item =~ /$par->{Country}/gs ) {
+            my ($rank) = $item =~ /<span class="geo_number descbold">([\d,]+)</i;
+
+            return $rank;
+        }
+    }
+  
+    return 0;
+}
+
 1;
 
 __END__
@@ -48,7 +80,10 @@ use WWW::Alexa::TrafficRank;
  
 my $tr = WWW::Alexa::TrafficRank->new();
  
-print $tr->get('filedir.com');
+my $rank = $tr->get('guruperl.net');
+my $country_rank = $tr->get_country_rank(Domain => 'guruperl.net', Country => 'United States');
+ 
+print $rank, "\n", $country_rank;
 
 =head1 DESCRIPTION
 
@@ -86,12 +121,18 @@ specified poxy. C<proxy> is the host which serve requests to Alexa.
 
 =over 4
 
-=item  $rank = $tr->get('filedir.com');
+=item  $rank = $tr->get('guruperl.net');
 
 Queries Alexa for a specified traffic rank URL and returns traffic rank
 text value. If query fails for some reason (Alexa unreachable, undefined 
 url passed) it return error string.
 
+=item  $country_rank = $tr->get_country_rank(Domain => 'guruperl.net', Country => 'United States');
+
+Extract the rank in the country. If we get a match on the country name in 
+the item then extract the ranking value and return. The country name must match the name 
+of the country as displayed on the Alexa page.
+
 =back
 
 =head1 BUGS
@@ -100,12 +141,13 @@ If you find any, please report ;)
 
 =head1 AUTHOR
 
-FileDir
-  F<E<lt>guruperl@cpan.orgE<gt>>.
-  
+Guruperl.net
+  F<E<lt>root@guruperl.netE<gt>>.
+  http://www.guruperl.net/
+
 =head1 COPYRIGHT
 
-Copyright 2016, FileDir, All Rights Reserved.
+Copyright 2009, Guruperl.net, All Rights Reserved.
 
 You may use, modify, and distribute this package under the
-same terms as Perl itself.
\ No newline at end of file
+same terms as Perl itself.
